@@ -3,10 +3,7 @@
 const browserAction = {};
 
 browserAction.show = function(tab, popupData) {
-    if (!popupData) {
-        popupData = page.popupData;
-    }
-
+    popupData ??= page.popupData;
     page.popupData = popupData;
 
     browser.browserAction.setIcon({
@@ -37,7 +34,13 @@ browserAction.showDefault = async function(tab) {
         popupData.iconType = 'locked';
     }
 
-    if (page.tabs[tab.id] && page.tabs[tab.id].loginList.length > 0) {
+    // Get the current tab if no tab given
+    tab ??= await getCurrentTab();
+    if (!tab) {
+        return;
+    }
+
+    if (page.tabs[tab.id]?.loginList.length > 0) {
         popupData.iconType = 'questionmark';
         popupData.popup = 'popup_login';
     }
@@ -45,21 +48,6 @@ browserAction.showDefault = async function(tab) {
     browserAction.show(tab, popupData);
 };
 
-browserAction.updateIcon = async function(tab, iconType) {
-    if (!tab) {
-        const tabs = await browser.tabs.query({ 'active': true, 'currentWindow': true });
-        if (tabs.length === 0) {
-            return;
-        }
-
-        tab = tabs[0];
-    }
-
-    browser.browserAction.setIcon({
-        path: browserAction.generateIconName(iconType)
-    });
-};
-
 browserAction.generateIconName = function(iconType) {
     let name = 'icon_';
     name += (keepass.keePassXCUpdateAvailable()) ? 'new_' : '';
@@ -70,10 +58,7 @@ browserAction.generateIconName = function(iconType) {
 
 browserAction.ignoreSite = async function(url) {
     await browser.windows.getCurrent();
-
-    // Get current active window
-    const tabs = await browser.tabs.query({ 'active': true, 'currentWindow': true });
-    const tab = tabs[0];
+    const tab = await getCurrentTab();
 
     // Send the message to the current tab's content script
     await browser.runtime.getBackgroundPage();
