@@ -15,8 +15,6 @@ keepass.latestVersionUrl = 'https://api.github.com/repos/keepassxreboot/keepassx
 keepass.cacheTimeout = 30 * 1000; // Milliseconds
 keepass.databaseHash = '';
 keepass.previousDatabaseHash = '';
-keepass.keyId = 'keepassxc-browser-cryptokey-name';
-keepass.keyBody = 'keepassxc-browser-key';
 keepass.reconnectLoop = null;
 
 const kpActions = {
@@ -112,9 +110,7 @@ keepass.retrieveCredentials = async function(tab, args = []) {
             return [];
         }
 
-        if (tab && page.tabs[tab.id]) {
-            page.tabs[tab.id].errorMessage = null;
-        }
+        keepass.clearErrorMessage(tab);
 
         if (!keepass.isConnected) {
             return [];
@@ -223,9 +219,7 @@ keepass.associate = async function(tab) {
             return AssociatedAction.NOT_ASSOCIATED;
         }
 
-        if (tab && page.tabs[tab.id]) {
-            page.tabs[tab.id].errorMessage = null;
-        }
+        keepass.clearErrorMessage(tab);
 
         const kpAction = kpActions.ASSOCIATE;
         const key = nacl.util.encodeBase64(keepass.keyPair.publicKey);
@@ -261,9 +255,7 @@ keepass.associate = async function(tab) {
 };
 
 keepass.testAssociation = async function(tab, args = []) {
-    if (tab && page.tabs[tab.id]) {
-        page.tabs[tab.id].errorMessage = null;
-    }
+    keepass.clearErrorMessage(tab);
 
     try {
         const [ enableTimeout = false, triggerUnlock = false ] = args;
@@ -316,9 +308,7 @@ keepass.testAssociation = async function(tab, args = []) {
             keepass.handleError(tab, kpErrors.ASSOCIATION_FAILED);
         } else {
             keepass.isEncryptionKeyUnrecognized = false;
-            if (tab && page.tabs[tab.id]) {
-                delete page.tabs[tab.id].errorMessage;
-            }
+            keepass.clearErrorMessage(tab);
         }
 
         return keepass.isAssociated();
@@ -492,9 +482,7 @@ keepass.getDatabaseGroups = async function(tab) {
             return [];
         }
 
-        if (tab && page.tabs[tab.id]) {
-            page.tabs[tab.id].errorMessage = null;
-        }
+        keepass.clearErrorMessage(tab);
 
         if (!keepass.isConnected) {
             return [];
@@ -534,9 +522,7 @@ keepass.createNewGroup = async function(tab, args = []) {
             return [];
         }
 
-        if (tab && page.tabs[tab.id]) {
-            page.tabs[tab.id].errorMessage = null;
-        }
+        keepass.clearErrorMessage(tab);
 
         if (!keepass.isConnected) {
             return [];
@@ -656,7 +642,7 @@ keepass.migrateKeyRing = function() {
 };
 
 keepass.saveKey = function(hash, id, key) {
-    if (!(hash in keepass.keyRing)) {
+    if (!Object.hasOwn(keepass.keyRing, hash)) {
         keepass.keyRing[hash] = {
             id: id,
             key: key,
@@ -675,7 +661,7 @@ keepass.saveKey = function(hash, id, key) {
 };
 
 keepass.updateLastUsed = function(hash) {
-    if ((hash in keepass.keyRing)) {
+    if (Object.hasOwn(keepass.keyRing, hash)) {
         keepass.keyRing[hash].lastUsed = new Date().valueOf();
         browser.storage.local.set({ 'keyRing': keepass.keyRing });
     }
@@ -703,6 +689,7 @@ keepass.deleteKey = function(hash) {
 keepass.getCryptoKey = function() {
     let dbkey = null;
     let dbid = null;
+
     if (!(keepass.databaseHash in keepass.keyRing)) {
         return [ dbid, dbkey ];
     }
@@ -724,7 +711,7 @@ keepass.setCryptoKey = function(id, key) {
 // Connection
 //--------------------------------------------------------------------------
 
-keepass.enableAutomaticReconnect = function() {
+keepass.enableAutomaticReconnect = async function() {
     // Disable for Windows if KeePassXC is older than 2.3.4
     if (!page.settings.autoReconnect
         || (navigator.platform.toLowerCase().includes('win')
@@ -758,8 +745,8 @@ keepass.reconnect = async function(tab, connectionTimeout) {
     }
 
     const hash = await keepass.getDatabaseHash(tab);
-    if (hash !== '' && tab && page.tabs[tab.id]) {
-        delete page.tabs[tab.id].errorMessage;
+    if (hash !== '') {
+        keepass.clearErrorMessage(tab);
     }
 
     await keepass.testAssociation();
@@ -779,7 +766,7 @@ keepass.generateNewKeyPair = function() {
 keepass.isConfigured = async function() {
     if (typeof(keepass.databaseHash) === 'undefined') {
         const hash = keepass.getDatabaseHash();
-        return hash in keepass.keyRing;
+        return Object.hasOwn(keepass.keyRing, hash);
     }
 
     return keepass.databaseHash in keepass.keyRing;
@@ -800,10 +787,11 @@ keepass.setcurrentKeePassXCVersion = function(version) {
 };
 
 keepass.keePassXCUpdateAvailable = function() {
-    if (page.settings.checkUpdateKeePassXC && page.settings.checkUpdateKeePassXC !== CHECK_UPDATE_NEVER) {
+    const checkUpdate = Number(page.settings.checkUpdateKeePassXC);
+    if (checkUpdate !== CHECK_UPDATE_NEVER) {
         const lastChecked = (keepass.latestKeePassXC.lastChecked) ? new Date(keepass.latestKeePassXC.lastChecked) : new Date(1986, 11, 21);
         const daysSinceLastCheck = Math.floor(((new Date()).getTime() - lastChecked.getTime()) / 86400000);
-        if (daysSinceLastCheck >= page.settings.checkUpdateKeePassXC) {
+        if (daysSinceLastCheck >= checkUpdate) {
             keepass.checkForNewKeePassXCVersion();
         }
 
@@ -844,6 +832,12 @@ keepass.checkForNewKeePassXCVersion = function() {
     keepass.latestKeePassXC.lastChecked = new Date().valueOf();
 };
 
+keepass.clearErrorMessage = function(tab) {
+    if (tab && page.tabs[tab.id]) {
+        page.tabs[tab.id].errorMessage = undefined;
+    }
+};
+
 keepass.handleError = function(tab, errorCode, errorMessage = '') {
     if (errorMessage.length === 0) {
         errorMessage = kpErrors.getError(errorCode);
@@ -855,9 +849,9 @@ keepass.handleError = function(tab, errorCode, errorMessage = '') {
     }
 };
 
-keepass.updatePopup = function(iconType) {
+keepass.updatePopup = function() {
     if (page && page.tabs.length > 0) {
-        browserAction.updateIcon(undefined, iconType);
+        browserAction.showDefault();
     }
 };
 
@@ -868,18 +862,17 @@ keepass.updateDatabase = async function() {
     page.clearAllLogins();
 
     await keepass.testAssociation(null, [ true ]);
-    const configured = await keepass.isConfigured();
 
-    keepass.updatePopup(configured ? 'normal' : 'locked');
+    keepass.updatePopup();
     keepass.updateDatabaseHashToContent();
 };
 
 keepass.updateDatabaseHashToContent = async function() {
     try {
-        const tabs = await browser.tabs.query({ active: true, currentWindow: true });
-        if (tabs.length) {
+        const tab = await getCurrentTab();
+        if (tab) {
             // Send message to content script
-            browser.tabs.sendMessage(tabs[0].id, {
+            browser.tabs.sendMessage(tab.id, {
                 action: 'check_database_hash',
                 hash: { old: keepass.previousDatabaseHash, new: keepass.databaseHash },
                 connected: keepass.isKeePassXCAvailable
