@@ -32,14 +32,10 @@ kpxcBanner.destroy = async function() {
 
 kpxcBanner.create = async function(credentials = {}) {
     const connectedDatabase = await sendMessage('get_connected_database');
-    if (!kpxc.settings.showLoginNotifications || kpxcBanner.created || connectedDatabase.identifier === null) {
-        return;
-    }
-
-    // Check if database is closed
-    const state = await sendMessage('check_database_hash');
-    if (state === '') {
-        //kpxcUI.createNotification('error', tr('rememberErrorDatabaseClosed'));
+    if (!kpxc.settings.showLoginNotifications
+        || kpxcBanner.created
+        || connectedDatabase.identifier === null
+        || kpxc.databaseState !== DatabaseState.UNLOCKED) {
         return;
     }
 
@@ -65,9 +61,9 @@ kpxcBanner.create = async function(credentials = {}) {
     const usernameText = kpxcUI.createElement('span', 'small', {}, tr('popupUsername') + ' ');
     const usernameSpan = kpxcUI.createElement('span', 'small info information-username', {}, credentials.username);
 
-    const newButton = kpxcUI.createElement('button', 'kpxc-button kpxc-green-button', { 'id': 'kpxc-banner-btn-new' }, tr('popupButtonNew'));
-    const updateButton = kpxcUI.createElement('button', 'kpxc-button kpxc-orange-button', { 'id': 'kpxc-banner-btn-update' }, tr('popupButtonUpdate'));
-    const dismissButton = kpxcUI.createElement('button', 'kpxc-button kpxc-red-button', { 'id': 'kpxc-banner-btn-dismiss' }, tr('popupButtonDismiss'));
+    const newButton = kpxcUI.createElement('button', GREEN_BUTTON, { 'id': 'kpxc-banner-btn-new' }, tr('popupButtonNew'));
+    const updateButton = kpxcUI.createElement('button', ORANGE_BUTTON, { 'id': 'kpxc-banner-btn-update' }, tr('popupButtonUpdate'));
+    const dismissButton = kpxcUI.createElement('button', RED_BUTTON, { 'id': 'kpxc-banner-btn-dismiss' }, tr('popupButtonDismiss'));
 
     const separator = kpxcUI.createElement('div', 'kpxc-separator');
     const ignoreCheckbox = kpxcUI.createElement('input', 'kpxc-checkbox', { type: 'checkbox', name: 'ignoreCheckbox', id: 'kpxc-banner-ignoreCheckbox' });
@@ -126,6 +122,8 @@ kpxcBanner.create = async function(credentials = {}) {
     const colorStyleSheet = createStylesheet('css/colors.css');
 
     const wrapper = document.createElement('div');
+    wrapper.style.display = 'none';
+    styleSheet.addEventListener('load', () => wrapper.style.display = 'block');
     this.shadowRoot = wrapper.attachShadow({ mode: 'closed' });
     this.shadowRoot.append(colorStyleSheet);
     this.shadowRoot.append(styleSheet);
@@ -188,7 +186,7 @@ kpxcBanner.saveNewCredentials = async function(credentials = {}) {
         }
     }
 
-    const addChildren = function(group, parentElement, depth) {
+    const addChildren = function(group, parentElement, depth = 0) {
         ++depth;
         const padding = depth * 20;
 
@@ -227,13 +225,12 @@ kpxcBanner.saveNewCredentials = async function(credentials = {}) {
     kpxcBanner.createGroupDialog();
 
     // Create the link list for group selection
-    let depth = 0;
     for (const g of result.groups) {
         const a = createLink(g.name, g.uuid, g.children.length > 0);
         a.setAttribute('id', 'root');
 
         kpxcBanner.shadowSelector('ul#list').appendChild(a);
-        addChildren(g, a, depth);
+        addChildren(g, a);
     }
 
     kpxcBanner.shadowSelector('.kpxc-banner-dialog').style.display = 'block';
@@ -241,11 +238,9 @@ kpxcBanner.saveNewCredentials = async function(credentials = {}) {
 
 kpxcBanner.updateCredentials = async function(credentials = {}) {
     //  Only one entry which could be updated
-    if (credentials.list.length === 1) {
+    if (credentials.list?.length === 1) {
         // Use the current username if it's empty
-        if (!credentials.username) {
-            credentials.username = credentials.list[0].login;
-        }
+        credentials.username ??= credentials.list[0].login;
 
         const res = await sendMessage('update_credentials', [ credentials.list[0].uuid, credentials.username, credentials.password, credentials.url ]);
         kpxcBanner.verifyResult(res);
@@ -262,8 +257,8 @@ kpxcBanner.updateCredentials = async function(credentials = {}) {
             kpxcBanner.shadowSelector('.kpxc-banner-dialog .username-exists').style.display = 'none';
         }
 
-        for (let i = 0; i < credentials.list.length; i++) {
-            const a = kpxcUI.createElement('a', 'list-group-item', { 'href': '#', 'entryId': i }, `${credentials.list[i].login} (${credentials.list[i].name})`);
+        for (const [ i, cred ] of credentials.list.entries()) {
+            const a = kpxcUI.createElement('a', 'list-group-item', { 'href': '#', 'entryId': i }, `${cred.login} (${cred.name})`);
             a.addEventListener('click', function(e) {
                 e.preventDefault();
                 if (!e.isTrusted) {
@@ -274,7 +269,7 @@ kpxcBanner.updateCredentials = async function(credentials = {}) {
 
                 // Use the current username if it's empty
                 if (!credentials.username) {
-                    credentials.username = credentials.list[entryId].login;
+                    credentials.username = cred.login;
                 }
 
                 let url = credentials.url;
@@ -295,7 +290,7 @@ kpxcBanner.updateCredentials = async function(credentials = {}) {
                 });
             });
 
-            if (credentials.usernameExists && credentials.username === credentials.list[i].login) {
+            if (credentials.usernameExists && credentials.username === cred.login) {
                 a.style.fontWeight = 'bold';
             }
 
@@ -325,7 +320,7 @@ kpxcBanner.verifyResult = async function(code) {
 
 // Traverse the groups and ensure all paths are found
 kpxcBanner.getDefaultGroup = function(groups, defaultGroup) {
-    const getGroup = function(group, splitted, depth) {
+    const getGroup = function(group, splitted, depth = -1) {
         ++depth;
         for (const g of group) {
             if (g.name === splitted[depth]) {
@@ -338,9 +333,8 @@ kpxcBanner.getDefaultGroup = function(groups, defaultGroup) {
         return [ '', '' ];
     };
 
-    let depth = -1;
     const splitted = defaultGroup.split('/');
-    return getGroup(groups, splitted, depth);
+    return getGroup(groups, splitted);
 };
 
 kpxcBanner.createCredentialDialog = async function() {
