@@ -56,10 +56,8 @@ kpxcFields.getAllCombinations = async function(inputs) {
         combinations.push(combination);
     }
 
-    // Check for multiple segmented TOTP fields
-    if (combinations.length === 0) {
-        kpxcFields.getSegmentedTOTPFields(inputs, combinations);
-    }
+    // Check for segmented TOTP fields
+    kpxcFields.handleSegmentedTOTPFields(inputs, combinations);
 
     return combinations;
 };
@@ -98,7 +96,7 @@ kpxcFields.getSegmentedTOTPFields = function(inputs, combinations) {
     let exceptionFound = false;
 
     const addTotpFieldsToCombination = function(inputFields, ignoreLength = false) {
-        const totpInputs = Array.from(inputFields).filter(e => e.nodeName === 'INPUT' && e.type !== 'password' && e.type !== 'hidden');
+        const totpInputs = Array.from(inputFields).filter(e => e.nodeName === 'INPUT' && e.type !== 'password' && e.type !== 'hidden' && e.type !== 'submit');
         if (totpInputs.length === DEFAULT_SEGMENTED_TOTP_FIELDS || ignoreLength) {
             const combination = {
                 form: form,
@@ -111,9 +109,9 @@ kpxcFields.getSegmentedTOTPFields = function(inputs, combinations) {
             combinations.push(combination);
 
             // Create an icon to the right side of the segmented fields
-            kpxcTOTPIcons.newIcon(totpInputs[totpInputs.length - 1], kpxc.databaseState, true);
+            kpxcTOTPIcons.newIcon(totpInputs.at(-1), kpxc.databaseState, true);
             kpxcIcons.icons.push({
-                field: totpInputs[totpInputs.length - 1],
+                field: totpInputs.at(-1),
                 iconType: kpxcIcons.iconTypes.TOTP,
                 segmented: true
             });
@@ -272,7 +270,7 @@ kpxcFields.getIdFromProperties = function(target) {
         return `${target.nodeName} ${target.type} ${target.name} ${target.placeholder}`;
     }
 
-    if (target.classList && target.classList.length > 0) {
+    if (target.classList?.length > 0) {
         return `${target.nodeName} ${target.type} ${target.classList.value} ${target.placeholder}`;
     }
 
@@ -285,11 +283,11 @@ kpxcFields.getIdFromProperties = function(target) {
 
 // Legacy unique ID generation for converting
 kpxcFields.getLegacyId = function(target) {
-    if (target.classList.length > 0) {
+    if (target.classList?.length > 0) {
         return `${target.nodeName} ${target.type} ${target.classList.value} ${target.name} ${target.placeholder}`;
     }
 
-    if (target.id && target.id !== '') {
+    if (target.id && target?.id !== '') {
         return `${target.nodeName} ${target.type} ${kpxcFields.prepareId(target.id)} ${target.name} ${target.placeholder}`;
     }
 
@@ -300,6 +298,26 @@ kpxcFields.getElementFromXPathId = function(xpath) {
     return (new XPathEvaluator()).evaluate(xpath, document.documentElement, null, XPathResult.FIRST_ORDERED_NODE_TYPE, null).singleNodeValue;
 };
 
+// Checks if inputs or combinations contain segmented TOTP fields
+kpxcFields.handleSegmentedTOTPFields = function(inputs, combinations) {
+    // Check for multiple segmented TOTP fields when there are no inputs, or combination contains the segemented fields
+    const segmentedFields = combinations.filter(c => c.totp);
+    if (combinations.length === 0 || segmentedFields.length === DEFAULT_SEGMENTED_TOTP_FIELDS) {
+        kpxcFields.getSegmentedTOTPFields(inputs, combinations);
+    }
+
+    // Remove previously detected segmented TOTP fields from the combination.
+    // This prevents adding icons to each single field when segmented fields are used.
+    if (segmentedFields.length === DEFAULT_SEGMENTED_TOTP_FIELDS) {
+        const firstTotpField = combinations.findIndex(c => c.totp);
+        if (firstTotpField >= 0) {
+            combinations.splice(firstTotpField, DEFAULT_SEGMENTED_TOTP_FIELDS);
+        }
+    }
+
+    return combinations;
+};
+
 // Check for new password via autocomplete attribute
 kpxcFields.isAutocompleteAppropriate = function(field) {
     const autocomplete = field.getLowerCaseAttribute('autocomplete');
@@ -316,14 +334,13 @@ kpxcFields.isCustomLoginFieldsUsed = function() {
 kpxcFields.isSearchForm = function(form) {
     // Check form action
     const formAction = form.getLowerCaseAttribute('action');
-    if (formAction && (formAction.includes('search') && !formAction.includes('research'))) {
+    if (formAction?.includes('search') && !formAction?.includes('research')) {
         return true;
     }
 
     // Ignore form with search classes
     const formId = form.getLowerCaseAttribute('id');
-    if (form.className && (form.className.includes('search')
-        || (formId && formId.includes('search') && !formId.includes('research')))) {
+    if (form.className?.includes('search') || (formId?.includes('search') && !formId?.includes('research'))) {
         return true;
     }
 
