@@ -103,7 +103,7 @@ kpxc.detectDatabaseChange = async function(response) {
     kpxcIcons.switchIcons();
 
     if (document.visibilityState !== 'hidden') {
-        if (response.hash.new !== '' && response.hash.new !== response.hash.old) {
+        if (response.hash.new !== '') {
             _called.retrieveCredentials = false;
             const settings = await sendMessage('load_settings');
             kpxc.settings = settings;
@@ -115,7 +115,7 @@ kpxc.detectDatabaseChange = async function(response) {
             // If user has requested a manual fill through context menu the actual credential filling
             // is handled here when the opened database has been regognized. It's not a pretty hack.
             const manualFill = await sendMessage('page_get_manual_fill');
-            if (manualFill !== ManualFill.NONE) {
+            if (manualFill !== ManualFill.NONE && kpxc.combinations.length > 0) {
                 await kpxcFill.fillInFromActiveElement(manualFill === ManualFill.PASSWORD);
                 await sendMessage('page_set_manual_fill', ManualFill.NONE);
             }
@@ -153,7 +153,7 @@ kpxc.getFormActionUrl = function(combination) {
     }
 
     let action = null;
-    if (combination.form && combination.form.length > 0) {
+    if (combination.form?.length > 0) {
         action = combination.form.action;
     }
 
@@ -386,13 +386,13 @@ kpxc.initLoginPopup = function() {
 
     // Initialize login items
     const loginItems = [];
-    for (let i = 0; i < kpxc.credentials.length; i++) {
-        const loginItem = getLoginItem(kpxc.credentials[i], showGroupNameInAutocomplete, i);
+    for (const [ i, login ] of kpxc.credentials.entries()) {
+        const loginItem = getLoginItem(login, showGroupNameInAutocomplete, i);
 
         // Ignore a duplicate entry if the password is empty, but there's already a similar entry with a password.
         // An usual use case with TOTP in a separate database.
         const similarEntryFound = kpxc.credentials.some(c => c.password !== '' && c.login === loginItem.login);
-        if (kpxc.credentials[i].password === '' && similarEntryFound) {
+        if (login.password === '' && similarEntryFound) {
             continue;
         }
 
@@ -586,7 +586,7 @@ kpxc.retrieveCredentials = async function(force = false) {
 // Handles credentials from 'retrieve_credentials' response
 kpxc.retrieveCredentialsCallback = async function(credentials) {
     _called.retrieveCredentials = true;
-    if (credentials && credentials.length > 0) {
+    if (credentials?.length > 0) {
         kpxc.credentials = credentials;
         await kpxc.prepareCredentials();
     }
@@ -599,7 +599,7 @@ kpxc.retrieveCredentialsCallback = async function(credentials) {
 
     // Retrieve submitted credentials if available
     const creds = await sendMessage('page_get_submitted');
-    if (creds && creds.submitted) {
+    if (creds?.submitted) {
         await sendMessage('page_clear_submitted');
         kpxc.rememberCredentials(creds.username, creds.password, creds.url, creds.oldCredentials);
     }
@@ -643,7 +643,7 @@ kpxc.setPasswordFilled = async function(state) {
 };
 
 // Special handling for settings value to select element
-kpxc.setValue = function(field, value) {
+kpxc.setValue = function(field, value, forced = false) {
     if (field.matches('select')) {
         value = value.toLowerCase().trim();
         const options = field.querySelectorAll('option');
@@ -658,11 +658,15 @@ kpxc.setValue = function(field, value) {
         return;
     }
 
-    kpxc.setValueWithChange(field, value);
+    kpxc.setValueWithChange(field, value, forced);
 };
 
 // Sets a new value to input field and triggers necessary events
-kpxc.setValueWithChange = function(field, value) {
+kpxc.setValueWithChange = function(field, value, forced = false) {
+    if (!forced && field.readOnly) {
+        return;
+    }
+
     field.value = value;
     field.dispatchEvent(new Event('input', { bubbles: true }));
     field.dispatchEvent(new Event('change', { bubbles: true }));
@@ -860,6 +864,12 @@ browser.runtime.onMessage.addListener(async function(req, sender) {
         } else if (req.action === 'fill_attribute' && req.args) {
             await kpxc.receiveCredentialsIfNecessary();
             kpxcFill.fillAttributeToActiveElementWith(req.args);
+        } else if (req.action === 'frame_message') {
+            if (req.args?.[0] === 'frame_request_to_frames' && window.self !== window.top) {
+                kpxcCustomLoginFieldsBanner.handleParentWindowMessage(req.args);
+            } else if (req.args?.[0] === 'frame_request_to_parent' && window.self === window.top) {
+                kpxcCustomLoginFieldsBanner.handleTopWindowMessage(req.args);
+            }
         } else if (req.action === 'ignore_site') {
             kpxc.ignoreSite(req.args);
         } else if (req.action === 'redetect_fields') {
